 Name - Govind Singla 
 Group - CS10
 Roll No. - 102016060
 Title - Mashup

## Description
This module will create a mashup sort of thing of any singer you want of any duration with just simple command.

## Requirements
 
pip install pytube
pip install pydub
Note - if you want to run this program, you must add these 3 files in your working directory - 
1. ffmpeg.exe
2. ffplay.exe
3. ffprobe.exe

## Install
Download the code using pip - 
pip install Govind-Singla-102016060

## Running the code using the following command
102016060 102016060.py "Sharry Mann" 20 20 102016060-output.mp3

